@@ -446,7 +446,8 @@ class PlaceService(BaseRdbmsService):
 
             keywords = string_util.string_to_keywords(' '.join([
                 row.get_value('name')
-                for row in cursor.fetch_all()]))
+                for row in cursor.fetch_all()
+            ]))
 
             if keywords:
                 connection.execute(
@@ -1584,8 +1585,8 @@ class PlaceService(BaseRdbmsService):
             cursor = connection.execute(
                 """
                 SELECT
-                    account_id
-                  FROM ONLY
+                    place_id
+                  FROM
                     place
                 """
             )
